@@ -27,59 +27,19 @@ from manila.network.neutron import constants as neutron_constants
 
 NEUTRON_GROUP = 'neutron'
 
-neutron_deprecated_opts = [
-    cfg.StrOpt(
-        'neutron_admin_username',
-        default='neutron',
-        deprecated_group='DEFAULT',
-        deprecated_for_removal=True,
-        deprecated_reason="This option isn't used any longer. Please use "
-                          "[neutron] username instead.",
-        help='Username for connecting to neutron in admin context.'),
-    cfg.StrOpt(
-        'neutron_admin_password',
-        help='Password for connecting to neutron in admin context.',
-        deprecated_group='DEFAULT',
-        deprecated_for_removal=True,
-        deprecated_reason="This option isn't used any longer. Please use "
-                          "[neutron] password instead.",
-        secret=True),
-    cfg.StrOpt(
-        'neutron_admin_project_name',
-        default='service',
-        deprecated_group='DEFAULT',
-        deprecated_name='neutron_admin_tenant_name',
-        deprecated_for_removal=True,
-        deprecated_reason="This option isn't used any longer. Please use "
-                          "[neutron] project instead.",
-        help='Project name for connecting to Neutron in admin context.'),
-    cfg.StrOpt(
-        'neutron_admin_auth_url',
-        default='http://localhost:5000/v2.0',
-        deprecated_group='DEFAULT',
-        deprecated_for_removal=True,
-        deprecated_reason="This option isn't used any longer. Please use "
-                          "[neutron] auth_url instead.",
-        help='Auth URL for connecting to neutron in admin context.'),
-]
 
 neutron_opts = [
     cfg.StrOpt(
         'url',
         default='http://127.0.0.1:9696',
-        deprecated_group="DEFAULT",
-        deprecated_name="neutron_url",
         help='URL for connecting to neutron.'),
     cfg.IntOpt(
         'url_timeout',
         default=30,
-        deprecated_group="DEFAULT",
-        deprecated_name="neutron_url_timeout",
         help='Timeout value for connecting to neutron in seconds.'),
     cfg.StrOpt(
         'auth_strategy',
         default='keystone',
-        deprecated_group="DEFAULT",
         help='Auth strategy for connecting to neutron in admin context.'),
     cfg.StrOpt(
         'endpoint_type',
@@ -90,18 +50,6 @@ neutron_opts = [
         help='Region name for connecting to neutron in admin context.'),
 ]
 
-# These fallback options can be removed in/after 9.0.0 (Train)
-deprecated_opts = {
-    'cafile': [
-        cfg.DeprecatedOpt('ca_certificates_file', group="DEFAULT"),
-        cfg.DeprecatedOpt('ca_certificates_file', group=NEUTRON_GROUP),
-    ],
-    'insecure': [
-        cfg.DeprecatedOpt('api_insecure', group="DEFAULT"),
-        cfg.DeprecatedOpt('api_insecure', group=NEUTRON_GROUP),
-    ],
-}
-
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
@@ -121,11 +69,9 @@ class API(object):
         self.config_group_name = config_group_name or 'DEFAULT'
 
         ks_loading.register_session_conf_options(
-            CONF, NEUTRON_GROUP, deprecated_opts=deprecated_opts)
+            CONF, NEUTRON_GROUP)
         ks_loading.register_auth_conf_options(CONF, NEUTRON_GROUP)
         CONF.register_opts(neutron_opts, NEUTRON_GROUP)
-        CONF.register_opts(neutron_deprecated_opts,
-                           group=self.config_group_name)
 
         self.configuration = getattr(CONF, self.config_group_name, CONF)
         self.last_neutron_extension_sync = None
@@ -138,18 +84,8 @@ class API(object):
 
     def get_client(self, context):
         if not self.auth_obj:
-            config = CONF[self.config_group_name]
-            v2_deprecated_opts = {
-                'username': config.neutron_admin_username,
-                'password': config.neutron_admin_password,
-                'tenant_name': config.neutron_admin_project_name,
-                'auth_url': config.neutron_admin_auth_url,
-            }
             self.auth_obj = client_auth.AuthClientLoader(
-                client_class=clientv20.Client,
-                exception_module=neutron_client_exc,
-                cfg_group=NEUTRON_GROUP,
-                deprecated_opts_for_v2=v2_deprecated_opts)
+                client_class=clientv20.Client, cfg_group=NEUTRON_GROUP)
 
         return self.auth_obj.get_client(
             self,
