@@ -846,7 +846,16 @@ class NativeProtocolHelper(ganesha.NASHelperBase):
         if share["share_group_id"] is not None:
             argdict.update({"group_name": share["share_group_id"]})
 
-        rados_command(self.rados_client, "fs subvolume deauthorize", argdict)
+        try:
+            rados_command(self.rados_client,
+                          "fs subvolume deauthorize",
+                          argdict)
+        except exception.ShareBackendException as e:
+            if "doesn't exist" in e.msg.lower():
+                LOG.warning(f"%{access['access_to']} did not have access to "
+                            f"share {share['id']}.")
+                return
+            raise e
         rados_command(self.rados_client, "fs subvolume evict", argdict)
 
     def update_access(self, context, share, access_rules, add_rules,
@@ -987,9 +996,16 @@ class NFSProtocolHelper(ganesha.GaneshaNASHelper2):
     def get_export_locations(self, share, subvolume_path):
         export_locations = []
         for export_ip in self.export_ips:
+            # Try to escape the export ip. If it fails, means that the
+            # `cephfs_ganesha_server_ip` wasn't possibly set and the used
+            # address is the hostname
+            try:
+                server_address = driver_helpers.escaped_address(export_ip)
+            except ValueError:
+                server_address = export_ip
+
             export_path = "{server_address}:{mount_path}".format(
-                server_address=driver_helpers.escaped_address(export_ip),
-                mount_path=subvolume_path)
+                server_address=server_address, mount_path=subvolume_path)
 
             LOG.info("Calculated export path for share %(id)s: %(epath)s",
                      {"id": share['id'], "epath": export_path})
