@@ -353,10 +353,11 @@ class ACCESSShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         path = self._nfs_add_str
         provider = '%s:%s' % (self.host, self._port)
         data = {}
-        va_share_info = ("{\"share\":[{\"fileSystemPath\":\""+va_sharepath +
+        va_share_info = ("{\"share\":[{\"fileSystemPath\":\"" + va_sharepath +
                          "\",\"shareType\":\"NFS\",\"shareDetails\":" +
-                         "[{\"client\":\""+server+"\",\"exportOptions\":\"" +
-                         access_level+"\"}]}]}")
+                         "[{\"client\":\"" + server +
+                         "\",\"exportOptions\":\"" +
+                         access_level + "\"}]}]}")
 
         data["shareDetails"] = va_share_info
 
@@ -396,9 +397,9 @@ class ACCESSShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         path = self._nfs_delete_str
         provider = '%s:%s' % (self.host, self._port)
         data = {}
-        va_share_info = ("{\"share\":[{\"fileSystemPath\":\""+va_sharepath +
+        va_share_info = ("{\"share\":[{\"fileSystemPath\":\"" + va_sharepath +
                          "\",\"shareType\":\"NFS\",\"shareDetails\":" +
-                         "[{\"client\":\""+server+"\"}]}]}")
+                         "[{\"client\":\"" + server + "\"}]}]}")
 
         data["shareDetails"] = va_share_info
         result = self._access_api(self.session, provider, path,
@@ -523,7 +524,7 @@ class ACCESSShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                                   json.dumps(data2), 'DELETE')
 
     def create_share_from_snapshot(self, ctx, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """create share from a snapshot."""
         sharename = snapshot['share_name']
         va_sharename = self._get_va_share_name(sharename)
@@ -621,6 +622,7 @@ class ACCESSShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             'total_capacity_gb': total_capacity,
             'free_capacity_gb': free_capacity,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'QoS_support': False,
             'snapshot_support': True,
             'create_share_from_snapshot_support': True
