@@ -13,17 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_serialization import jsonutils
-import six
 import webob
 
 from manila.api.v1 import share_snapshots
 from manila.common import constants
 from manila import context
 from manila import db
-from manila import exception
 from manila.share import api as share_api
 from manila import test
 from manila.tests.api.contrib import stubs
@@ -37,7 +36,7 @@ class ShareSnapshotAPITest(test.TestCase):
     """Share Snapshot API Test."""
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareSnapshotAPITest, self).setUp()
         self.controller = share_snapshots.ShareSnapshotsController()
 
         self.mock_object(share_api.API, 'get', stubs.stub_share_get)
@@ -65,7 +64,7 @@ class ShareSnapshotAPITest(test.TestCase):
         }
         self.mock_object(share_api.API, 'get_snapshot',
                          mock.Mock(return_value=return_snapshot))
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/fake/snapshots/200')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show,
                           req, '200')
@@ -82,7 +81,7 @@ class ShareSnapshotAPITest(test.TestCase):
                 'description': 'displaysnapdesc',
             }
         }
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/fake/snapshots')
 
         res_dict = self.controller.create(req, body)
 
@@ -105,7 +104,7 @@ class ShareSnapshotAPITest(test.TestCase):
                 'description': 'fake_share_description',
             }
         }
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/fake/snapshots')
 
         self.assertRaises(
             webob.exc.HTTPUnprocessableEntity,
@@ -115,7 +114,7 @@ class ShareSnapshotAPITest(test.TestCase):
 
     def test_snapshot_create_no_body(self):
         body = {}
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/fake/snapshots')
         self.assertRaises(webob.exc.HTTPUnprocessableEntity,
                           self.controller.create,
                           req,
@@ -124,21 +123,21 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_delete(self):
         self.mock_object(share_api.API, 'delete_snapshot',
                          stubs.stub_snapshot_delete)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/fake/snapshots/200')
         resp = self.controller.delete(req, 200)
         self.assertEqual(202, resp.status_int)
 
     def test_snapshot_delete_nofound(self):
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get_notfound)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/fake/snapshots/200')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.delete,
                           req,
                           200)
 
     def test_snapshot_show(self):
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/fake/snapshots/200')
         res_dict = self.controller.show(req, 200)
         expected = fake_share.expected_snapshot(id=200)
         self.assertEqual(expected, res_dict)
@@ -146,7 +145,7 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_show_nofound(self):
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get_notfound)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/fake/snapshots/200')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show,
                           req, '200')
@@ -154,7 +153,7 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_list_summary(self):
         self.mock_object(share_api.API, 'get_all_snapshots',
                          stubs.stub_snapshot_get_all_by_project)
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/fake/snapshots')
         res_dict = self.controller.index(req)
         expected = {
             'snapshots': [
@@ -163,12 +162,12 @@ class ShareSnapshotAPITest(test.TestCase):
                     'id': 2,
                     'links': [
                         {
-                            'href': 'http://localhost/v1/fake/'
+                            'href': 'http://localhost/share/v1/fake/'
                                     'snapshots/2',
                             'rel': 'self'
                         },
                         {
-                            'href': 'http://localhost/fake/snapshots/2',
+                            'href': 'http://localhost/share/fake/snapshots/2',
                             'rel': 'bookmark'
                         }
                     ],
@@ -180,12 +179,12 @@ class ShareSnapshotAPITest(test.TestCase):
     def _snapshot_list_summary_with_search_opts(self, use_admin_context):
         search_opts = fake_share.search_opts()
         # fake_key should be filtered for non-admin
-        url = '/snapshots?fake_key=fake_value'
+        url = '/fake/snapshots?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(url, use_admin_context=use_admin_context)
 
-        snapshots = [
+        db_snapshots = [
             {'id': 'id1', 'display_name': 'n1',
              'status': 'fake_status', 'share_id': 'fake_share_id'},
             {'id': 'id2', 'display_name': 'n2',
@@ -193,6 +192,7 @@ class ShareSnapshotAPITest(test.TestCase):
             {'id': 'id3', 'display_name': 'n3',
              'status': 'fake_status', 'share_id': 'fake_share_id'},
         ]
+        snapshots = [db_snapshots[1]]
         self.mock_object(share_api.API, 'get_all_snapshots',
                          mock.Mock(return_value=snapshots))
 
@@ -207,14 +207,16 @@ class ShareSnapshotAPITest(test.TestCase):
             search_opts_expected.update({'fake_key': 'fake_value'})
         share_api.API.get_all_snapshots.assert_called_once_with(
             req.environ['manila.context'],
+            limit=int(search_opts['limit']),
+            offset=int(search_opts['offset']),
             sort_key=search_opts['sort_key'],
             sort_dir=search_opts['sort_dir'],
             search_opts=search_opts_expected,
         )
         self.assertEqual(1, len(result['snapshots']))
-        self.assertEqual(snapshots[1]['id'], result['snapshots'][0]['id'])
+        self.assertEqual(snapshots[0]['id'], result['snapshots'][0]['id'])
         self.assertEqual(
-            snapshots[1]['display_name'], result['snapshots'][0]['name'])
+            snapshots[0]['display_name'], result['snapshots'][0]['name'])
 
     def test_snapshot_list_summary_with_search_opts_by_non_admin(self):
         self._snapshot_list_summary_with_search_opts(use_admin_context=False)
@@ -225,12 +227,12 @@ class ShareSnapshotAPITest(test.TestCase):
     def _snapshot_list_detail_with_search_opts(self, use_admin_context):
         search_opts = fake_share.search_opts()
         # fake_key should be filtered for non-admin
-        url = '/shares/detail?fake_key=fake_value'
+        url = '/fake/shares/detail?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(url, use_admin_context=use_admin_context)
 
-        snapshots = [
+        db_snapshots = [
             {
                 'id': 'id1',
                 'display_name': 'n1',
@@ -253,6 +255,7 @@ class ShareSnapshotAPITest(test.TestCase):
                 'share_id': 'fake_share_id',
             },
         ]
+        snapshots = [db_snapshots[1]]
 
         self.mock_object(share_api.API, 'get_all_snapshots',
                          mock.Mock(return_value=snapshots))
@@ -268,18 +271,20 @@ class ShareSnapshotAPITest(test.TestCase):
             search_opts_expected.update({'fake_key': 'fake_value'})
         share_api.API.get_all_snapshots.assert_called_once_with(
             req.environ['manila.context'],
+            limit=int(search_opts['limit']),
+            offset=int(search_opts['offset']),
             sort_key=search_opts['sort_key'],
             sort_dir=search_opts['sort_dir'],
             search_opts=search_opts_expected,
         )
         self.assertEqual(1, len(result['snapshots']))
-        self.assertEqual(snapshots[1]['id'], result['snapshots'][0]['id'])
+        self.assertEqual(snapshots[0]['id'], result['snapshots'][0]['id'])
         self.assertEqual(
-            snapshots[1]['display_name'], result['snapshots'][0]['name'])
+            snapshots[0]['display_name'], result['snapshots'][0]['name'])
         self.assertEqual(
-            snapshots[1]['status'], result['snapshots'][0]['status'])
+            snapshots[0]['status'], result['snapshots'][0]['status'])
         self.assertEqual(
-            snapshots[1]['share_id'], result['snapshots'][0]['share_id'])
+            snapshots[0]['share_id'], result['snapshots'][0]['share_id'])
 
     def test_snapshot_list_detail_with_search_opts_by_non_admin(self):
         self._snapshot_list_detail_with_search_opts(use_admin_context=False)
@@ -289,7 +294,7 @@ class ShareSnapshotAPITest(test.TestCase):
 
     def test_snapshot_list_detail(self):
         env = {'QUERY_STRING': 'name=Share+Test+Name'}
-        req = fakes.HTTPRequest.blank('/shares/detail', environ=env)
+        req = fakes.HTTPRequest.blank('/fake/shares/detail', environ=env)
         res_dict = self.controller.detail(req)
         expected_s = fake_share.expected_snapshot(id=2)
         expected = {'snapshots': [expected_s['snapshot']]}
@@ -297,14 +302,6 @@ class ShareSnapshotAPITest(test.TestCase):
 
     def test_snapshot_list_status_none(self):
         snapshots = [
-            {
-                'id': 2,
-                'share_id': 'fakeshareid',
-                'size': 1,
-                'status': 'fakesnapstatus',
-                'name': 'displaysnapname',
-                'description': 'displaysnapdesc',
-            },
             {
                 'id': 3,
                 'share_id': 'fakeshareid',
@@ -316,7 +313,7 @@ class ShareSnapshotAPITest(test.TestCase):
         ]
         self.mock_object(share_api.API, 'get_all_snapshots',
                          mock.Mock(return_value=snapshots))
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/fake/snapshots')
         result = self.controller.index(req)
         self.assertEqual(1, len(result['snapshots']))
         self.assertEqual(snapshots[0]['id'], result['snapshots'][0]['id'])
@@ -325,7 +322,7 @@ class ShareSnapshotAPITest(test.TestCase):
         snp = self.snp_example
         body = {"snapshot": snp}
 
-        req = fakes.HTTPRequest.blank('/snapshot/1')
+        req = fakes.HTTPRequest.blank('/fake/snapshot/1')
         res_dict = self.controller.update(req, 1, body)
         self.assertEqual(snp["display_name"], res_dict['snapshot']["name"])
 
@@ -333,7 +330,7 @@ class ShareSnapshotAPITest(test.TestCase):
         snp = self.snp_example
         body = {"snapshot": snp}
 
-        req = fakes.HTTPRequest.blank('/snapshot/1')
+        req = fakes.HTTPRequest.blank('/fake/snapshot/1')
         res_dict = self.controller.update(req, 1, body)
 
         self.assertEqual(snp["display_description"],
@@ -343,7 +340,7 @@ class ShareSnapshotAPITest(test.TestCase):
         snp = self.snp_example
         body = {"snapshot": snp}
 
-        req = fakes.HTTPRequest.blank('/snapshot/1')
+        req = fakes.HTTPRequest.blank('/fake/snapshot/1')
         res_dict = self.controller.update(req, 1, body)
 
         self.assertNotEqual(snp["size"], res_dict['snapshot']["size"])
@@ -353,9 +350,9 @@ class ShareSnapshotAPITest(test.TestCase):
 class ShareSnapshotAdminActionsAPITest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareSnapshotAdminActionsAPITest, self).setUp()
         self.controller = share_snapshots.ShareSnapshotsController()
-        self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
+        self.flags(transport_url='rabbit://fake:fake@mqhost:5672')
         self.admin_context = context.RequestContext('admin', 'fake', True)
         self.member_context = context.RequestContext('fake', 'fake')
 
@@ -378,7 +375,7 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
             body = {action_name: {'status': constants.STATUS_ERROR}}
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
@@ -386,14 +383,8 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.NotFound,
-                              db_access_method,
-                              ctxt,
-                              model['id'])
-        else:
-            actual_model = db_access_method(ctxt, model['id'])
-            self.assertEqual(valid_status, actual_model['status'])
+        actual_model = db_access_method(ctxt, model['id'])
+        self.assertEqual(valid_status, actual_model['status'])
 
     @ddt.data(*fakes.fixture_reset_status_with_different_roles_v1)
     @ddt.unpack
@@ -420,7 +411,7 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
         action_name = 'os-force_delete'
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
-        req.body = six.b(jsonutils.dumps({action_name: {}}))
+        req.body = jsonutils.dumps({action_name: {}}).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
