@@ -15,7 +15,6 @@ from unittest import mock
 import ddt
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import six
 from webob import exc as webob_exc
 
 from manila.api.openstack import api_version_request
@@ -97,7 +96,7 @@ class ShareInstancesAPITest(test.TestCase):
             req_context, self.resource_name, 'index')
 
     def test_index_with_limit(self):
-        req = self._get_request('/share_instances')
+        req = self._get_request('/v2/fake/share_instances')
         req_context = req.environ['manila.context']
         share_instances_count = 3
         test_instances = [
@@ -107,13 +106,13 @@ class ShareInstancesAPITest(test.TestCase):
         expect_links = [
             {
                 'href': (
-                    'http://localhost/v1/fake/share_instances?'
+                    'http://localhost/share/v2/fake/share_instances?'
                     'limit=3&marker=%s' % test_instances[2]['id']),
                 'rel': 'next',
             }
         ]
 
-        url = 'share_instances?limit=3'
+        url = '/v2/fake/share_instances?limit=3'
         req = self._get_request(url)
         actual_result = self.controller.index(req)
 
@@ -185,7 +184,7 @@ class ShareInstancesAPITest(test.TestCase):
         req = self._get_request('fake', version=version)
         req_context = req.environ['manila.context']
         share_policy_check_call = mock.call(
-            req_context, 'share', 'get', mock.ANY)
+            req_context, 'share', 'get', mock.ANY, do_raise=False)
         get_instances_policy_check_call = mock.call(
             req_context, 'share_instance', 'index')
 
@@ -246,7 +245,7 @@ class ShareInstancesAPITest(test.TestCase):
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
         req.headers['X-Openstack-Manila-Api-Version'] = version
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         with mock.patch.object(
@@ -310,7 +309,7 @@ class ShareInstancesAPITest(test.TestCase):
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
         req.headers['X-Openstack-Manila-Api-Version'] = version
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         with mock.patch.object(
