@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_serialization import jsonutils
-import six
 import webob
 
 from manila.api.openstack import api_version_request as api_version
@@ -55,7 +55,7 @@ class ShareSnapshotAPITest(test.TestCase):
     """Share Snapshot API Test."""
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareSnapshotAPITest, self).setUp()
         self.controller = share_snapshots.ShareSnapshotsController()
 
         self.mock_object(share_api.API, 'get', stubs.stub_share_get)
@@ -86,7 +86,10 @@ class ShareSnapshotAPITest(test.TestCase):
                 'description': 'displaysnapdesc',
             }
         }
-        req = fakes.HTTPRequest.blank('/snapshots', version=version)
+        url = ('/v2/fake/snapshots'
+               if version.startswith('2.')
+               else '/v1/fake/snapshots')
+        req = fakes.HTTPRequest.blank(url, version=version)
 
         res_dict = self.controller.create(req, body)
 
@@ -109,7 +112,7 @@ class ShareSnapshotAPITest(test.TestCase):
                 'description': 'fake_share_description',
             }
         }
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots')
 
         self.assertRaises(
             webob.exc.HTTPUnprocessableEntity,
@@ -119,7 +122,7 @@ class ShareSnapshotAPITest(test.TestCase):
 
     def test_snapshot_create_no_body(self):
         body = {}
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots')
         self.assertRaises(webob.exc.HTTPUnprocessableEntity,
                           self.controller.create,
                           req,
@@ -128,14 +131,14 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_delete(self):
         self.mock_object(share_api.API, 'delete_snapshot',
                          stubs.stub_snapshot_delete)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/200')
         resp = self.controller.delete(req, 200)
         self.assertEqual(202, resp.status_int)
 
     def test_snapshot_delete_nofound(self):
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get_notfound)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/200')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.delete,
                           req,
@@ -143,7 +146,8 @@ class ShareSnapshotAPITest(test.TestCase):
 
     @ddt.data('2.0', '2.16', '2.17')
     def test_snapshot_show(self, version):
-        req = fakes.HTTPRequest.blank('/snapshots/200', version=version)
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/200',
+                                      version=version)
         expected = fake_share.expected_snapshot(version=version, id=200)
 
         res_dict = self.controller.show(req, 200)
@@ -153,7 +157,7 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_show_nofound(self):
         self.mock_object(share_api.API, 'get_snapshot',
                          stubs.stub_snapshot_get_notfound)
-        req = fakes.HTTPRequest.blank('/snapshots/200')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/200')
         self.assertRaises(webob.exc.HTTPNotFound,
                           self.controller.show,
                           req, '200')
@@ -161,7 +165,7 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_list_summary(self):
         self.mock_object(share_api.API, 'get_all_snapshots',
                          stubs.stub_snapshot_get_all_by_project)
-        req = fakes.HTTPRequest.blank('/snapshots')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots')
         res_dict = self.controller.index(req)
         expected = {
             'snapshots': [
@@ -170,12 +174,12 @@ class ShareSnapshotAPITest(test.TestCase):
                     'id': 2,
                     'links': [
                         {
-                            'href': 'http://localhost/v1/fake/'
+                            'href': 'http://localhost/share/v2/fake/'
                                     'snapshots/2',
                             'rel': 'self'
                         },
                         {
-                            'href': 'http://localhost/fake/snapshots/2',
+                            'href': 'http://localhost/share/fake/snapshots/2',
                             'rel': 'bookmark'
                         }
                     ],
@@ -192,17 +196,18 @@ class ShareSnapshotAPITest(test.TestCase):
             search_opts.pop('name')
             search_opts['display_name~'] = 'fake_name'
         # fake_key should be filtered for non-admin
-        url = '/snapshots?fake_key=fake_value'
+        url = '/v2/fake/snapshots?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(
             url, use_admin_context=use_admin_context, version=version)
 
-        snapshots = [
+        db_snapshots = [
             {'id': 'id1', 'display_name': 'n1', 'status': 'fake_status', },
             {'id': 'id2', 'display_name': 'n2', 'status': 'fake_status', },
             {'id': 'id3', 'display_name': 'n3', 'status': 'fake_status', },
         ]
+        snapshots = [db_snapshots[1]]
         self.mock_object(share_api.API, 'get_all_snapshots',
                          mock.Mock(return_value=snapshots))
 
@@ -221,14 +226,16 @@ class ShareSnapshotAPITest(test.TestCase):
             search_opts_expected.update({'fake_key': 'fake_value'})
         share_api.API.get_all_snapshots.assert_called_once_with(
             req.environ['manila.context'],
+            limit=int(search_opts['limit']),
+            offset=int(search_opts['offset']),
             sort_key=search_opts['sort_key'],
             sort_dir=search_opts['sort_dir'],
             search_opts=search_opts_expected,
         )
         self.assertEqual(1, len(result['snapshots']))
-        self.assertEqual(snapshots[1]['id'], result['snapshots'][0]['id'])
+        self.assertEqual(snapshots[0]['id'], result['snapshots'][0]['id'])
         self.assertEqual(
-            snapshots[1]['display_name'], result['snapshots'][0]['name'])
+            snapshots[0]['display_name'], result['snapshots'][0]['name'])
 
     @ddt.data({'version': '2.35', 'use_admin_context': True},
               {'version': '2.36', 'use_admin_context': True},
@@ -243,12 +250,12 @@ class ShareSnapshotAPITest(test.TestCase):
     def _snapshot_list_detail_with_search_opts(self, use_admin_context):
         search_opts = fake_share.search_opts()
         # fake_key should be filtered for non-admin
-        url = '/shares/detail?fake_key=fake_value'
+        url = '/v2/fake/shares/detail?fake_key=fake_value'
         for k, v in search_opts.items():
             url = url + '&' + k + '=' + v
         req = fakes.HTTPRequest.blank(url, use_admin_context=use_admin_context)
 
-        snapshots = [
+        db_snapshots = [
             {
                 'id': 'id1',
                 'display_name': 'n1',
@@ -269,6 +276,7 @@ class ShareSnapshotAPITest(test.TestCase):
                 'aggregate_status': 'fake_status',
             },
         ]
+        snapshots = [db_snapshots[1]]
 
         self.mock_object(share_api.API, 'get_all_snapshots',
                          mock.Mock(return_value=snapshots))
@@ -284,18 +292,20 @@ class ShareSnapshotAPITest(test.TestCase):
             search_opts_expected.update({'fake_key': 'fake_value'})
         share_api.API.get_all_snapshots.assert_called_once_with(
             req.environ['manila.context'],
+            limit=int(search_opts['limit']),
+            offset=int(search_opts['offset']),
             sort_key=search_opts['sort_key'],
             sort_dir=search_opts['sort_dir'],
             search_opts=search_opts_expected,
         )
         self.assertEqual(1, len(result['snapshots']))
-        self.assertEqual(snapshots[1]['id'], result['snapshots'][0]['id'])
+        self.assertEqual(snapshots[0]['id'], result['snapshots'][0]['id'])
         self.assertEqual(
-            snapshots[1]['display_name'], result['snapshots'][0]['name'])
+            snapshots[0]['display_name'], result['snapshots'][0]['name'])
         self.assertEqual(
-            snapshots[1]['aggregate_status'], result['snapshots'][0]['status'])
+            snapshots[0]['aggregate_status'], result['snapshots'][0]['status'])
         self.assertEqual(
-            snapshots[1]['share_id'], result['snapshots'][0]['share_id'])
+            snapshots[0]['share_id'], result['snapshots'][0]['share_id'])
 
     def test_snapshot_list_detail_with_search_opts_by_non_admin(self):
         self._snapshot_list_detail_with_search_opts(use_admin_context=False)
@@ -306,7 +316,8 @@ class ShareSnapshotAPITest(test.TestCase):
     @ddt.data('2.0', '2.16', '2.17')
     def test_snapshot_list_detail(self, version):
         env = {'QUERY_STRING': 'name=Share+Test+Name'}
-        req = fakes.HTTPRequest.blank('/snapshots/detail', environ=env,
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/detail',
+                                      environ=env,
                                       version=version)
         expected_s = fake_share.expected_snapshot(version=version, id=2)
         expected = {'snapshots': [expected_s['snapshot']]}
@@ -319,7 +330,7 @@ class ShareSnapshotAPITest(test.TestCase):
     def test_snapshot_updates_display_name_and_description(self, version):
         snp = self.snp_example
         body = {"snapshot": snp}
-        req = fakes.HTTPRequest.blank('/snapshot/1', version=version)
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshot/1', version=version)
 
         res_dict = self.controller.update(req, 1, body)
 
@@ -337,7 +348,7 @@ class ShareSnapshotAPITest(test.TestCase):
         snp = self.snp_example
         body = {"snapshot": snp}
 
-        req = fakes.HTTPRequest.blank('/snapshot/1')
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshot/1')
         res_dict = self.controller.update(req, 1, body)
 
         self.assertNotEqual(snp["size"], res_dict['snapshot']["size"])
@@ -357,7 +368,7 @@ class ShareSnapshotAPITest(test.TestCase):
                          mock.Mock(return_value=expected))
 
         id = 'fake_snap_id'
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % id,
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/%s/action' % id,
                                       version='2.32')
 
         actual = self.controller.access_list(req, id)
@@ -387,8 +398,8 @@ class ShareSnapshotAPITest(test.TestCase):
         allow_access = self.mock_object(share_api.API, 'snapshot_allow_access',
                                         mock.Mock(return_value=access))
         body = {'allow_access': access}
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version=version)
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version=version)
 
         actual = self.controller.allow_access(req, snapshot['id'], body)
 
@@ -405,8 +416,8 @@ class ShareSnapshotAPITest(test.TestCase):
         share = db_utils.create_share(mount_snapshot_support=True)
         snapshot = db_utils.create_snapshot(
             status=constants.STATUS_AVAILABLE, share_id=share['id'])
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
         body = {}
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -417,8 +428,8 @@ class ShareSnapshotAPITest(test.TestCase):
         share = db_utils.create_share(mount_snapshot_support=True)
         snapshot = db_utils.create_snapshot(
             status=constants.STATUS_AVAILABLE, share_id=share['id'])
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
         access = {
             'id': 'fake_id',
             'access_type': 'ip',
@@ -467,8 +478,8 @@ class ShareSnapshotAPITest(test.TestCase):
                                mock.Mock(return_value=share))
 
         body = {'allow_access': access}
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.allow_access, req,
@@ -489,8 +500,8 @@ class ShareSnapshotAPITest(test.TestCase):
                   'access_to': ''}
 
         body = {'allow_access': access}
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.allow_access, req,
@@ -512,8 +523,8 @@ class ShareSnapshotAPITest(test.TestCase):
         deny_access = self.mock_object(share_api.API, 'snapshot_deny_access')
 
         body = {'deny_access': {'access_id': access.id}}
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
 
         resp = self.controller.deny_access(req, snapshot['id'], body)
 
@@ -532,8 +543,8 @@ class ShareSnapshotAPITest(test.TestCase):
         share = db_utils.create_share(mount_snapshot_support=True)
         snapshot = db_utils.create_snapshot(
             status=constants.STATUS_AVAILABLE, share_id=share['id'])
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
         body = {}
 
         self.assertRaises(webob.exc.HTTPBadRequest,
@@ -560,8 +571,8 @@ class ShareSnapshotAPITest(test.TestCase):
                                       mock.Mock(return_value=wrong_access))
 
         body = {'deny_access': {'access_id': access.id}}
-        req = fakes.HTTPRequest.blank('/snapshots/%s/action' % snapshot['id'],
-                                      version='2.32')
+        req = fakes.HTTPRequest.blank(
+            '/v2/fake/snapshots/%s/action' % snapshot['id'], version='2.32')
 
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller.deny_access, req, snapshot['id'],
@@ -579,19 +590,19 @@ class ShareSnapshotAPITest(test.TestCase):
 class ShareSnapshotAdminActionsAPITest(test.TestCase):
 
     def setUp(self):
-        super(self.__class__, self).setUp()
+        super(ShareSnapshotAdminActionsAPITest, self).setUp()
         self.controller = share_snapshots.ShareSnapshotsController()
-        self.flags(rpc_backend='manila.openstack.common.rpc.impl_fake')
+        self.flags(transport_url='rabbit://fake:fake@mqhost:5672')
         self.admin_context = context.RequestContext('admin', 'fake', True)
         self.member_context = context.RequestContext('fake', 'fake')
 
         self.resource_name = self.controller.resource_name
         self.manage_request = fakes.HTTPRequest.blank(
-            '/snapshots/manage', use_admin_context=True,
+            '/v2/fake/snapshots/manage', use_admin_context=True,
             version=MIN_MANAGE_SNAPSHOT_API_VERSION)
         self.snapshot_id = 'fake'
         self.unmanage_request = fakes.HTTPRequest.blank(
-            '/snapshots/%s/unmanage' % self.snapshot_id,
+            '/v2/fake/snapshots/%s/unmanage' % self.snapshot_id,
             use_admin_context=True,
             version=MIN_MANAGE_SNAPSHOT_API_VERSION)
 
@@ -618,7 +629,7 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
         req.headers['X-Openstack-Manila-Api-Version'] = version
-        req.body = six.b(jsonutils.dumps(body))
+        req.body = jsonutils.dumps(body).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
@@ -626,14 +637,8 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
         # validate response code and model status
         self.assertEqual(valid_code, resp.status_int)
 
-        if valid_code == 404:
-            self.assertRaises(exception.NotFound,
-                              db_access_method,
-                              ctxt,
-                              model['id'])
-        else:
-            actual_model = db_access_method(ctxt, model['id'])
-            self.assertEqual(valid_status, actual_model['status'])
+        actual_model = db_access_method(ctxt, model['id'])
+        self.assertEqual(valid_status, actual_model['status'])
 
     @ddt.data(*fakes.fixture_reset_status_with_different_roles)
     @ddt.unpack
@@ -668,7 +673,7 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
         req.method = 'POST'
         req.headers['content-type'] = 'application/json'
         req.headers['X-Openstack-Manila-Api-Version'] = version
-        req.body = six.b(jsonutils.dumps({action_name: {}}))
+        req.body = jsonutils.dumps({action_name: {}}).encode("utf-8")
         req.environ['manila.context'] = ctxt
 
         resp = req.get_response(fakes.app())
@@ -739,8 +744,9 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
             'display_description': 'bar',
         }
 
-        req = fakes.HTTPRequest.blank(
-            '/snapshots/manage', use_admin_context=True, version=version)
+        req = fakes.HTTPRequest.blank('/v2/fake/snapshots/manage',
+                                      use_admin_context=True,
+                                      version=version)
 
         actual_result = self.controller.manage(req, data)
 
@@ -798,13 +804,27 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
             share_id='fake', provider_location='fake_volume_snapshot_id',
             driver_options={})
         fake_req = fakes.HTTPRequest.blank(
-            '/snapshots/manage', use_admin_context=True,
+            '/v2/fake/snapshots/manage', use_admin_context=True,
             version=version)
 
         self.assertRaises(exception.VersionNotFoundForAPIMethod,
                           self.controller.manage,
                           fake_req, body)
 
+    def test_snapshot__unmanage(self):
+        body = {}
+        snapshot = {'status': constants.STATUS_AVAILABLE, 'id': 'bar_id',
+                    'share_id': 'bar_id'}
+        fake_req = fakes.HTTPRequest.blank('/v2/fake/snapshots/unmanage',
+                                           use_admin_context=True,
+                                           version='2.49')
+        mock_unmanage = self.mock_object(self.controller, '_unmanage')
+
+        self.controller.unmanage(fake_req, snapshot['id'], body)
+
+        mock_unmanage.assert_called_once_with(fake_req, snapshot['id'], body,
+                                              allow_dhss_true=True)
+
     def test_snapshot_unmanage_share_server(self):
         self.mock_policy_check = self.mock_object(
             policy, 'check_policy', mock.Mock(return_value=True))
@@ -938,10 +958,40 @@ class ShareSnapshotAdminActionsAPITest(test.TestCase):
     def test_unmanage_version_not_found(self, version):
         snapshot_id = 'fake'
         fake_req = fakes.HTTPRequest.blank(
-            '/snapshots/%s/unmanage' % snapshot_id,
+            '/v2/fake/snapshots/%s/unmanage' % snapshot_id,
             use_admin_context=True,
             version=version)
 
         self.assertRaises(exception.VersionNotFoundForAPIMethod,
                           self.controller.unmanage,
                           fake_req, 'fake')
+
+    def test_snapshot_unmanage_dhss_true_with_share_server(self):
+        self.mock_policy_check = self.mock_object(
+            policy, 'check_policy', mock.Mock(return_value=True))
+        share = {'status': constants.STATUS_AVAILABLE, 'id': 'bar_id',
+                 'host': 'fake_host',
+                 'share_server_id': 'fake'}
+        mock_get = self.mock_object(share_api.API, 'get',
+                                    mock.Mock(return_value=share))
+        snapshot = {'status': constants.STATUS_AVAILABLE, 'id': 'bar_id',
+                    'share_id': 'bar_id'}
+        self.mock_object(share_api.API, 'get_snapshot',
+                         mock.Mock(return_value=snapshot))
+        self.mock_object(share_api.API, 'unmanage_snapshot')
+
+        actual_result = self.controller._unmanage(self.unmanage_request,
+                                                  snapshot['id'],
+                                                  allow_dhss_true=True)
+
+        self.assertEqual(202, actual_result.status_int)
+        self.controller.share_api.get_snapshot.assert_called_once_with(
+            self.unmanage_request.environ['manila.context'], snapshot['id'])
+        share_api.API.unmanage_snapshot.assert_called_once_with(
+            mock.ANY, snapshot, 'fake_host')
+        mock_get.assert_called_once_with(
+            self.unmanage_request.environ['manila.context'], snapshot['id']
+        )
+        self.mock_policy_check.assert_called_once_with(
+            self.unmanage_request.environ['manila.context'],
+            self.resource_name, 'unmanage_snapshot')
