@@ -19,11 +19,11 @@ Tests For HostManager
 """
 
 import copy
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
-from six import moves
 
 from manila import context
 from manila import db
@@ -57,7 +57,7 @@ class HostManagerTestCase(test.TestCase):
         super(HostManagerTestCase, self).setUp()
         self.host_manager = host_manager.HostManager()
         self.fake_hosts = [host_manager.HostState('fake_host%s' % x)
-                           for x in moves.range(1, 5)]
+                           for x in range(1, 5)]
 
     def test_choose_host_filters_not_found(self):
         self.flags(scheduler_default_filters='FakeFilterClass3')
@@ -107,26 +107,19 @@ class HostManagerTestCase(test.TestCase):
 
     def test_update_service_capabilities_for_shares(self):
         service_states = self.host_manager.service_states
-        self.assertDictMatch(service_states, {})
+        self.assertDictEqual(service_states, {})
         host1_share_capabs = dict(free_capacity_gb=4321, timestamp=1)
         host2_share_capabs = dict(free_capacity_gb=5432, timestamp=1)
         host3_share_capabs = dict(free_capacity_gb=6543, timestamp=1)
         service_name = 'share'
-        with mock.patch.object(timeutils, 'utcnow',
-                               mock.Mock(return_value=31337)):
-            self.host_manager.update_service_capabilities(
-                service_name, 'host1', host1_share_capabs)
-            timeutils.utcnow.assert_called_once_with()
-        with mock.patch.object(timeutils, 'utcnow',
-                               mock.Mock(return_value=31338)):
-            self.host_manager.update_service_capabilities(
-                service_name, 'host2', host2_share_capabs)
-            timeutils.utcnow.assert_called_once_with()
-        with mock.patch.object(timeutils, 'utcnow',
-                               mock.Mock(return_value=31339)):
-            self.host_manager.update_service_capabilities(
-                service_name, 'host3', host3_share_capabs)
-            timeutils.utcnow.assert_called_once_with()
+        self.host_manager.update_service_capabilities(
+            service_name, 'host1', host1_share_capabs, 31337)
+
+        self.host_manager.update_service_capabilities(
+            service_name, 'host2', host2_share_capabs, 31338)
+
+        self.host_manager.update_service_capabilities(
+            service_name, 'host3', host3_share_capabs, 31339)
 
         # Make sure dictionary isn't re-assigned
         self.assertEqual(service_states, self.host_manager.service_states)
@@ -142,7 +135,7 @@ class HostManagerTestCase(test.TestCase):
             'host2': host2_share_capabs,
             'host3': host3_share_capabs,
         }
-        self.assertDictMatch(service_states, expected)
+        self.assertDictEqual(service_states, expected)
 
     def test_get_all_host_states_share(self):
         fake_context = context.RequestContext('user', 'project')
@@ -171,7 +164,7 @@ class HostManagerTestCase(test.TestCase):
 
             self.assertEqual(3, len(host_state_map))
             # Check that service is up
-            for i in moves.range(3):
+            for i in range(3):
                 share_node = fakes.SHARE_SERVICES_WITH_POOLS[i]
                 host = share_node['host']
                 self.assertEqual(share_node, host_state_map[host].service)
@@ -204,6 +197,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 312,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -219,6 +213,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -232,6 +227,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 400,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -247,6 +243,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -260,6 +257,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 10000,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 50000,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -275,6 +273,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 },
             ]
@@ -310,6 +309,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 51,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 10,
                         'max_over_subscription_ratio': 1.0,
                         'thin_provisioning': False,
@@ -325,6 +325,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -339,6 +340,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -354,6 +356,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -368,6 +371,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 53,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 100,
                         'max_over_subscription_ratio': 20.0,
                         'thin_provisioning': True,
@@ -383,6 +387,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -397,6 +402,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 541,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 800,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -412,6 +418,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -426,6 +433,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 542,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 2000,
                         'max_over_subscription_ratio': 10.0,
                         'thin_provisioning': True,
@@ -441,6 +449,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 },
             ]
@@ -493,6 +502,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 512,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 312,
@@ -503,6 +513,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -521,6 +532,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 256,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'vendor_name': None,
                         'storage_protocol': None,
                         'provisioned_capacity_gb': 400,
@@ -531,6 +543,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 },
             ]
@@ -577,6 +590,7 @@ class HostManagerTestCase(test.TestCase):
                         'driver_version': None,
                         'total_capacity_gb': 52,
                         'reserved_percentage': 0,
+                        'reserved_snapshot_percentage': 0,
                         'provisioned_capacity_gb': 60,
                         'max_over_subscription_ratio': 2.0,
                         'thin_provisioning': True,
@@ -587,6 +601,7 @@ class HostManagerTestCase(test.TestCase):
                         'replication_type': None,
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
+                        'security_service_update_support': False,
                     },
                 },
             ]
@@ -640,6 +655,7 @@ class HostStateTestCase(test.TestCase):
         share_capability = {'total_capacity_gb': 0,
                             'free_capacity_gb': 100,
                             'reserved_percentage': 0,
+                            'reserved_snapshot_percentage': 0,
                             'timestamp': None,
                             'ipv4_support': True,
                             'ipv6_support': False}
@@ -692,6 +708,7 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 270,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'dying_disks': 100,
                  'super_hero_1': 'spider-man',
                  'super_hero_2': 'flash',
@@ -703,6 +720,7 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 0,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'dying_disks': 200,
                  'super_hero_1': 'superman',
                  'super_hero_2': 'Hulk',
@@ -748,6 +766,7 @@ class HostStateTestCase(test.TestCase):
                  'allocated_capacity_gb': 0,
                  'qos': 'False',
                  'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  },
             ],
             'timestamp': None,
@@ -774,6 +793,7 @@ class HostStateTestCase(test.TestCase):
             'free_capacity_gb': 'unknown',
             'allocated_capacity_gb': 1,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -802,6 +822,7 @@ class HostStateTestCase(test.TestCase):
             'provisioned_capacity_gb': provisioned_capacity_gb,
             'allocated_capacity_gb': provisioned_capacity_gb,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'timestamp': None
         }
         fake_host = host_manager.PoolState('host1', share_capability, '_pool0')
@@ -823,6 +844,7 @@ class HostStateTestCase(test.TestCase):
             'provisioned_capacity_gb': None,
             'allocated_capacity_gb': 0,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
             'timestamp': None
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
@@ -860,6 +882,7 @@ class HostStateTestCase(test.TestCase):
             'allocated_capacity_gb': 5000,
             'timestamp': None,
             'reserved_percentage': 0,
+            'reserved_snapshot_percentage': 0,
         }
         fake_context = context.RequestContext('user', 'project', is_admin=True)
         fake_host = host_manager.HostState('host1')
@@ -882,6 +905,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': True,
                  'cap1': 'val1', 'cap2': 'val2'},
             'instances':
@@ -904,6 +928,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': False, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -925,6 +950,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -946,6 +972,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2'},
             'instances':
@@ -968,6 +995,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'cap1': 'val1', 'cap2': 'val2', 'ipv4_support': True,
                  'ipv6_support': False},
             'instances': []
@@ -976,6 +1004,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': True, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -984,6 +1013,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': [False], 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -992,6 +1022,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'reserved_percentage': 0, 'timestamp': None,
+                 'reserved_snapshot_percentage': 0,
                  'thin_provisioning': [True, False], 'cap1': 'val1',
                  'cap2': 'val2', 'ipv4_support': True, 'ipv6_support': False},
             'instances': []
@@ -1000,6 +1031,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': True
                  },
@@ -1017,6 +1049,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': True, 'ipv6_support': True},
             'instances': []
@@ -1025,6 +1058,7 @@ class PoolStateTestCase(test.TestCase):
             'share_capability':
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'provisioned_capacity_gb': 256, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2',
                  'ipv4_support': False, 'ipv6_support': False
                  },
@@ -1043,6 +1077,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': True, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1059,6 +1094,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1075,6 +1111,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 1,
                  'thin_provisioning': [True, False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1091,6 +1128,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': False, 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1107,6 +1145,7 @@ class PoolStateTestCase(test.TestCase):
                 {'total_capacity_gb': 1024, 'free_capacity_gb': 512,
                  'allocated_capacity_gb': 256, 'provisioned_capacity_gb': 256,
                  'thin_provisioning': [False], 'reserved_percentage': 0,
+                 'reserved_snapshot_percentage': 0,
                  'timestamp': None, 'cap1': 'val1', 'cap2': 'val2'},
             'instances':
                 [
@@ -1135,7 +1174,7 @@ class PoolStateTestCase(test.TestCase):
         self.assertEqual('pool0', fake_pool.pool_name)
         self.assertEqual(1024, fake_pool.total_capacity_gb)
         self.assertEqual(512, fake_pool.free_capacity_gb)
-        self.assertDictMatch(share_capability, fake_pool.capabilities)
+        self.assertDictEqual(share_capability, dict(fake_pool.capabilities))
 
         if 'thin_provisioning' in share_capability:
             thin_provisioned = scheduler_utils.thin_provisioning(
