@@ -140,7 +140,8 @@ class ShareDriverTestCase(test.TestCase):
             'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
-            'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'reserved_percentage', 'reserved_snapshot_percentage',
+            'vendor_name', 'storage_protocol',
             'snapshot_support', 'mount_snapshot_support',
         ]
         share_driver = driver.ShareDriver(True, configuration=conf)
@@ -581,6 +582,64 @@ class ShareDriverTestCase(test.TestCase):
                           share_driver.migration_get_progress,
                           None, None, None, None, None, None, None)
 
+    def test_share_server_migration_start(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+
+        self.assertRaises(NotImplementedError,
+                          share_driver.share_server_migration_start,
+                          None, None, None, None, None)
+
+    def test_share_server_migration_continue(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+
+        self.assertRaises(NotImplementedError,
+                          share_driver.share_server_migration_continue,
+                          None, None, None, None, None)
+
+    def test_share_server_migration_get_progress(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+
+        self.assertRaises(NotImplementedError,
+                          share_driver.share_server_migration_get_progress,
+                          None, None, None, None, None)
+
+    def test_share_server_migration_cancel(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+
+        self.assertRaises(NotImplementedError,
+                          share_driver.share_server_migration_cancel,
+                          None, None, None, None, None)
+
+    def test_share_server_migration_check_compatibility(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+        expected_compatibility = {
+            'compatible': False,
+            'writable': False,
+            'nondisruptive': False,
+            'preserve_snapshots': False,
+            'migration_cancel': False,
+            'migration_get_progress': False,
+        }
+
+        driver_compatibility = (
+            share_driver.share_server_migration_check_compatibility(
+                None, None, None, None, None, None))
+        self.assertEqual(expected_compatibility, driver_compatibility)
+
+    def test_share_server_migration_complete(self):
+        driver.CONF.set_default('driver_handles_share_servers', True)
+        share_driver = driver.ShareDriver(True)
+
+        self.assertRaises(
+            NotImplementedError,
+            share_driver.share_server_migration_complete,
+            None, None, None, None, None, None)
+
     @ddt.data(True, False)
     def test_connection_get_info(self, admin):
 
@@ -887,6 +946,31 @@ class ShareDriverTestCase(test.TestCase):
         self.assertIsNone(share_group_update)
         self.assertEqual(expected_share_updates, share_update)
 
+    def test_update_share_server_security_service(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(NotImplementedError,
+                          share_driver.update_share_server_security_service,
+                          'fake_context',
+                          {'id', 'share_server_id'},
+                          {'fake', 'fake_net_info'},
+                          [{"id": "fake_instance_id"}],
+                          [{"id": "fake_rule_id"}],
+                          {'id', 'fake_sec_service_id'},
+                          current_security_service=None)
+
+    def test_check_update_share_server_security_service(self):
+        share_driver = self._instantiate_share_driver(None, True)
+        self.assertRaises(
+            NotImplementedError,
+            share_driver.check_update_share_server_security_service,
+            'fake_context',
+            {'id', 'share_server_id'},
+            {'fake', 'fake_net_info'},
+            [{"id": "fake_instance_id"}],
+            [{"id": "fake_rule_id"}],
+            {'id', 'fake_sec_service_id'},
+            current_security_service=None)
+
     def test_create_share_group_from_sg_snapshot_with_no_members(self):
         share_driver = self._instantiate_share_driver(None, False)
         fake_share_group_dict = {}
